@@ -5,6 +5,7 @@ from typing import List
 
 from cc_py_commons.carriers.contact import Contact
 from cc_py_commons.carriers.account_carrier_map import AccountCarrierMap
+from cc_py_commons.lanes.lane import Lane
 @dataclass
 class Carrier:
       
@@ -60,4 +61,5 @@ class Carrier:
   lane_count: int = field(default=0)
   internal_remarks: str = field(default=None)
   contact: Contact = field(default=None)
-  account_carrier_maps: List[AccountCarrierMap] = field(default_factory=lambda: [])
\ No newline at end of file
+  account_carrier_maps: List[AccountCarrierMap] = field(default_factory=lambda: [])
+  lanes: List[Lane] = field(default_factory=lambda: [])
\ No newline at end of file
