@@ -9,4 +9,7 @@ class LocationSchema(CamelCaseSchema):
   state = fields.String()
   postcode = fields.String(allow_none=True)
   county = fields.String(allow_none=True) 
-  country = fields.String(allow_none=True)
\ No newline at end of file
+  country = fields.String(allow_none=True)
+  latitude = fields.Float(allow_none=True)
+  longitude = fields.Float(allow_none=True)
+  
\ No newline at end of file
