@@ -91,3 +91,5 @@ class Transaction:
     # generated by server and returned
     id: uuid.UUID = field(default=None)
     pieces: int = field(default=None)
+    max_temperature: float = field(default=None)
+    min_temperature: float = field(default=None)
